@@ -2,7 +2,7 @@ use strict;
 use warnings;
 
 package Footprintless::App::Command::service;
-$Footprintless::App::Command::service::VERSION = '1.10';
+$Footprintless::App::Command::service::VERSION = '1.11';
 use Footprintless::App -command;
 use Footprintless::Util qw(exit_due_to);
 use Log::Any;
@@ -12,13 +12,6 @@ my $logger = Log::Any->get_logger();
 # ABSTRACT: Performs an action on a service.
 # PODNAME: Footprintless::App::Command::service
 
-sub _configure_logging {
-    my ( $self, $level ) = @_;
-    require Log::Any::Adapter;
-    Log::Any::Adapter->set( 'Stderr',
-        log_level => Log::Any::Adapter::Util::numeric_level($level) );
-}
-
 sub execute {
     my ( $self, $opts, $args ) = @_;
     my ( $coordinate, $action ) = @$args;
@@ -37,10 +30,6 @@ sub execute {
     }
 }
 
-sub opt_spec {
-    return ( [ "log=s", "will set the log level", ], );
-}
-
 sub usage_desc {
     return "fpl service [COORDINATE] [ACTION] %o";
 }
@@ -76,7 +65,7 @@ Footprintless::App::Command::service - Performs an action on a service.
 
 =head1 VERSION
 
-version 1.10
+version 1.11
 
 =head1 SYNOPSIS
 
