@@ -2,10 +2,12 @@ use strict;
 use warnings;
 
 package Footprintless::Deployment;
-$Footprintless::Deployment::VERSION = '1.10';
+$Footprintless::Deployment::VERSION = '1.11';
 # ABSTRACT: A deployment manager
 # PODNAME: Footprintless::Deployment
 
+use parent qw(Footprintless::MixableBase);
+
 use Carp;
 use File::Path qw(
     make_path
@@ -26,10 +28,6 @@ use Log::Any;
 
 my $logger = Log::Any->get_logger();
 
-sub new {
-    return bless( {}, shift )->_init(@_);
-}
-
 sub clean {
     my ( $self, @options ) = @_;
     $self->_clean(@options);
@@ -71,25 +69,17 @@ sub _deploy_resources {
     foreach my $resource_name (@names) {
         my $resource = $resources->{$resource_name};
         if ( ref($resource) eq 'HASH' && $resource->{extract_to} ) {
-            $self->_extract_resource( $resource,
-                File::Spec->catdir( $to_dir, $resource->{extract_to} ) );
+            my $extract_dir = File::Spec->catdir( $to_dir, $resource->{extract_to} );
+            $logger->tracef( 'extract [%s] to [%s]', $resource, $to_dir );
+            $self->_extract_resource( $resource, $extract_dir );
         }
         else {
+            $logger->tracef( 'download [%s] to [%s]', $resource, $to_dir );
             $self->_download( $resource, $to_dir );
         }
     }
 }
 
-sub _init {
-    my ( $self, $factory, $coordinate, %options ) = @_;
-    $logger->tracef( "coordinate=[%s]\noptions=[%s]", $coordinate, \%options );
-
-    $self->{factory}    = $factory;
-    $self->{coordinate} = $coordinate;
-
-    return $self;
-}
-
 sub _local_template {
     my ( $self, $local_work, @options ) = @_;
     $self->Footprintless::Mixins::_local_template(
@@ -121,7 +111,7 @@ Footprintless::Deployment - A deployment manager
 
 =head1 VERSION
 
-version 1.10
+version 1.11
 
 =head1 SYNOPSIS
 
