@@ -2,10 +2,12 @@ use strict;
 use warnings;
 
 package Footprintless::Overlay;
-$Footprintless::Overlay::VERSION = '1.10';
+$Footprintless::Overlay::VERSION = '1.11';
 # ABSTRACT: An overlay manager
 # PODNAME: Footprintless::Overlay
 
+use parent qw(Footprintless::MixableBase);
+
 use Carp;
 use Footprintless::Mixins qw (
     _clean
@@ -29,10 +31,6 @@ use Template::Overlay;
 
 my $logger = Log::Any->get_logger();
 
-sub new {
-    return bless( {}, shift )->_init(@_);
-}
-
 sub clean {
     my ($self) = @_;
     $self->_clean();
@@ -72,16 +70,6 @@ sub _dot_footprintless_resolver {
     };
 }
 
-sub _init {
-    my ( $self, $factory, $coordinate, %options ) = @_;
-    $logger->tracef( "coordinate=[%s],options=[%s]", $coordinate, \%options );
-
-    $self->{factory}    = $factory;
-    $self->{coordinate} = $coordinate;
-
-    return $self;
-}
-
 sub initialize {
     my ( $self, %options ) = @_;
 
@@ -213,7 +201,7 @@ Footprintless::Overlay - An overlay manager
 
 =head1 VERSION
 
-version 1.10
+version 1.11
 
 =head1 SYNOPSIS
 
